@@ -27,7 +27,12 @@
 /* Hildon includes */
 #ifdef IS_HILDON
 
+#if HILDON_VER > 0
+#include <hildon/hildon-program.h>
+#else
 #include <hildon-widgets/hildon-program.h>
+#endif /* HILDON_VER */
+
 #include <gpe/pim-categories-ui.h>
 
 #define ICON_PATH "/usr/share/icons/hicolor/26x26/hildon"
@@ -630,9 +635,11 @@ window_key_press_event (GtkWidget *window, GdkEventKey *k, GtkWidget *data)
       case GDK_F6:
         gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (fullscreen_control), 
              !gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (fullscreen_control)));
-        break;
+        return TRUE;
+      break;
 #endif
       }
+    return FALSE;
 }
 
 static GtkItemFactoryEntry menu_items[] =
